@@ -342,6 +342,20 @@ class Model:
         self.dupdate = True
 
     def st(self, *arg):
+        """
+        Define constraints that an optimization model subject to.
+
+        Parameters
+        ----------
+        *args
+            Constraints or collections of constraints that the model
+            subject to.
+        
+        Notes
+        -----
+        Multiple constraints can be defined altogether as the argument
+        of the st method.
+        """
 
         for constr in arg:
             if isinstance(constr, Iterable):
@@ -363,6 +377,16 @@ class Model:
         self.dupdate = True
 
     def do_math(self, primal=True):
+        """
+        Return the linear or second-order cone programming problem
+        as the standard formula or robust counterpart of the model.
+
+        Parameters
+        ----------
+        primal : bool, default True
+            Specify whether return the primal formula of the model.
+            If primal=False, the method returns the daul formula.
+        """
 
         if primal:
             if self.primal is not None and not self.pupdate:
@@ -666,9 +690,17 @@ class Model:
         self.solution = solution
 
     def get(self):
+        """
+        Return the optimal objective value of the solved model.
+
+        Notes
+        -----
+        An error message is given if the model is unsolved or no solution
+        is obtained.
+        """
 
         if self.solution is None:
-            raise RuntimeError('The model is unsolved or infeasible.')
+            raise RuntimeError('The model is unsolved or no solution is obtained')
         return self.sign * self.solution.objval
 
     def optimal(self):
@@ -677,6 +709,9 @@ class Model:
 
 
 class Ambiguity:
+    """
+    The Ambiguity class creates an ambiguity set object
+    """
 
     def __init__(self, model):
 
@@ -702,6 +737,10 @@ class Ambiguity:
         return self.s.__repr__()
 
     def showevents(self):
+        """
+        Return a data frame showing how the event-wise support sets and
+        uncertainty sets of random variable expectations are defined.
+        """
 
         num_scen = self.model.num_scen
         table = pd.DataFrame([False]*num_scen,
@@ -712,7 +751,6 @@ class Ambiguity:
                                        index=self.s.series.index))
         table.loc[defined, 'support'] = True
 
-        # exp_cosntr = self.model.exp_constr
         exp_constr_indices = self.exp_constr_indices
         count = 0
         for indices in exp_constr_indices:
